@@ -1,16 +1,40 @@
 
+#define PACKAGE_NAME ""
+#define PACKAGE_TARNAME ""
+#define PACKAGE_VERSION ""
+#define PACKAGE_STRING ""
+#define PACKAGE_BUGREPORT ""
+#define USE_BUILTIN_FRAME_ADDRESS 1
+#define STDC_HEADERS 1
+#define HAVE_SYS_TYPES_H 1
+#define HAVE_SYS_STAT_H 1
+#define HAVE_STDLIB_H 1
+#define HAVE_STRING_H 1
+#define HAVE_MEMORY_H 1
+#define HAVE_STRINGS_H 1
+#define HAVE_INTTYPES_H 1
+#define HAVE_STDINT_H 1
+#define HAVE_UNISTD_H 1
+#define HAVE_LONG_LONG 1
+#define HAVE_OFF_T 1
 #define SIZEOF_INT 4
 #define SIZEOF_SHORT 2
 #define SIZEOF_LONG 4
 #define SIZEOF_LONG_LONG 8
 #define SIZEOF___INT64 0
+#define SIZEOF_OFF_T 8
 #define SIZEOF_VOIDP 4
 #define SIZEOF_FLOAT 4
 #define SIZEOF_DOUBLE 8
+#define SIZEOF_TIME_T 4
+#define rb_pid_t pid_t
+#define rb_gid_t gid_t
+#define rb_uid_t uid_t
 #define HAVE_PROTOTYPES 1
 #define TOKEN_PASTE(x,y) x##y
 #define HAVE_STDARG_PROTOTYPES 1
-#define HAVE_ATTR_NORETURN 1
+#define NORETURN(x) x __attribute__ ((noreturn))
+#define HAVE_DECL_SYS_NERR 1
 #define HAVE_DIRENT_H 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_WAIT_H 1
@@ -27,20 +51,30 @@
 #define HAVE_SYS_TIMES_H 1
 #define HAVE_SYS_PARAM_H 1
 #define HAVE_PWD_H 1
+#define HAVE_GRP_H 1
 #define HAVE_A_OUT_H 1
 #define HAVE_UTIME_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_SYS_RESOURCE_H 1
+#define HAVE_SYS_UTIME_H 1
+#define HAVE_NETINET_IN_SYSTM_H 1
+#define HAVE_FLOAT_H 1
+#define HAVE_IEEEFP_H 1
+#define HAVE_PTHREAD_H 1
+#define HAVE_STRUCT_STAT_ST_BLKSIZE 1
 #define HAVE_ST_BLKSIZE 1
+#define HAVE_STRUCT_STAT_ST_BLOCKS 1
 #define HAVE_ST_BLOCKS 1
+#define HAVE_STRUCT_STAT_ST_RDEV 1
 #define HAVE_ST_RDEV 1
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_ALLOCA_H 1
 #define HAVE_ALLOCA 1
+#define HAVE_FSEEKO 1
+#define HAVE_FTELLO 1
 #define HAVE_DUP2 1
 #define HAVE_MEMMOVE 1
-#define HAVE_MKDIR 1
 #define HAVE_STRCASECMP 1
 #define HAVE_STRNCASECMP 1
 #define HAVE_STRERROR 1
@@ -48,54 +82,71 @@
 #define HAVE_STRCHR 1
 #define HAVE_STRSTR 1
 #define HAVE_STRTOUL 1
+#define HAVE_FLOCK 1
 #define HAVE_VSNPRINTF 1
-#define HAVE_ISINF 1
 #define HAVE_ISNAN 1
 #define HAVE_FINITE 1
+#define HAVE_ISINF 1
+#define HAVE_HYPOT 1
+#define HAVE_ACOSH 1
+#define HAVE_ERF 1
 #define HAVE_FMOD 1
 #define HAVE_KILLPG 1
-#define HAVE_DRAND48 1
-#define HAVE_RANDOM 1
 #define HAVE_WAIT4 1
 #define HAVE_WAITPID 1
-#define HAVE_GETCWD 1
 #define HAVE_CHROOT 1
+#define HAVE_FSYNC 1
+#define HAVE_GETCWD 1
 #define HAVE_TRUNCATE 1
 #define HAVE_TIMES 1
 #define HAVE_UTIMES 1
 #define HAVE_FCNTL 1
 #define HAVE_LSTAT 1
 #define HAVE_SYMLINK 1
+#define HAVE_LINK 1
 #define HAVE_READLINK 1
 #define HAVE_SETEUID 1
+#define HAVE_SETREUID 1
 #define HAVE_SETEGID 1
+#define HAVE_SETREGID 1
 #define HAVE_PAUSE 1
+#define HAVE_LCHOWN 1
 #define HAVE_GETPGRP 1
 #define HAVE_SETPGRP 1
 #define HAVE_GETPGID 1
 #define HAVE_SETPGID 1
+#define HAVE_INITGROUPS 1
 #define HAVE_GETGROUPS 1
+#define HAVE_SETGROUPS 1
 #define HAVE_DLOPEN 1
 #define HAVE_SIGPROCMASK 1
 #define HAVE_SIGACTION 1
-#define HAVE__SETJMP 1
 #define HAVE_SETSID 1
 #define HAVE_TELLDIR 1
 #define HAVE_SEEKDIR 1
 #define HAVE_FCHMOD 1
-#define HAVE_INITSTATE 1
+#define HAVE_MKTIME 1
+#define HAVE_COSH 1
+#define HAVE_SINH 1
+#define HAVE_TANH 1
+#define HAVE_SETUID 1
+#define HAVE_SETGID 1
+#define NEGATIVE_TIME_T 1
 #define POSIX_SIGNAL 1
 #define GETPGRP_VOID 1
 #define SETPGRP_VOID 1
 #define RSHIFT(x,y) ((x)>>(int)y)
 #define FILE_COUNT _r
+#define FILE_READPTR _p
+#define NEED_IO_SEEK_BETWEEN_RW 1
+#define HUGE_ST_INO 1
+#define STACK_GROW_DIRECTION -1
 #define DEFAULT_KCODE KCODE_NONE
-#define USE_ELF 1
 #define DLEXT ".so"
 #define DLEXT2 ".dll"
-#define RUBY_LIB "/lib/ruby/1.6"
+#define RUBY_LIB "/lib/ruby/1.8"
 #define RUBY_SITE_LIB "/lib/ruby/site_ruby"
-#define RUBY_SITE_LIB2 "/lib/ruby/site_ruby/1.6"
+#define RUBY_SITE_LIB2 "/lib/ruby/site_ruby/1.8"
 #define RUBY_PLATFORM "i386-cygwin"
-#define RUBY_ARCHLIB "/lib/ruby/1.6/i386-cygwin"
-#define RUBY_SITE_ARCHLIB "/lib/ruby/site_ruby/1.6/i386-cygwin"
+#define RUBY_ARCHLIB "/lib/ruby/1.8/i386-cygwin"
+#define RUBY_SITE_ARCHLIB "/lib/ruby/site_ruby/1.8/i386-cygwin"
